summaryrefslogtreecommitdiff
path: root/xmake/modules/detect/tools/find_sdar.lua
diff options
context:
space:
mode:
authorruki <[email protected]>2020-09-28 23:09:23 +0800
committerruki <[email protected]>2020-09-28 23:09:23 +0800
commit0c52f3a6ab4397c5be94c3293f4ae20d6b7a8b94 (patch)
treec6bacf9de25b6af942b5e7ac83bca8aa3cf1e5ce /xmake/modules/detect/tools/find_sdar.lua
parent34e395ad9281d17382b1d1c5a4e7828a259720f0 (diff)
rename some pathes to paths
Diffstat (limited to 'xmake/modules/detect/tools/find_sdar.lua')
-rw-r--r--xmake/modules/detect/tools/find_sdar.lua12
1 files changed, 6 insertions, 6 deletions
diff --git a/xmake/modules/detect/tools/find_sdar.lua b/xmake/modules/detect/tools/find_sdar.lua
index 48d055bdf..eafa1a5da 100644
--- a/xmake/modules/detect/tools/find_sdar.lua
+++ b/xmake/modules/detect/tools/find_sdar.lua
@@ -40,17 +40,17 @@ function main(opt)
opt = opt or {}
opt.command = opt.command or "--version"
- -- add search pathes
- local pathes = {}
+ -- add search paths
+ local paths = {}
local bindir = get_config("bin")
if bindir and os.isdir(bindir) then
- table.insert(pathes, bindir)
+ table.insert(paths, bindir)
end
if is_host("windows") then
- table.insert(pathes, "$(reg HKEY_LOCAL_MACHINE\\SOFTWARE\\WOW6432Node\\SDCC)\\bin")
+ table.insert(paths, "$(reg HKEY_LOCAL_MACHINE\\SOFTWARE\\WOW6432Node\\SDCC)\\bin")
end
- if #pathes > 0 then
- opt.pathes = pathes
+ if #paths > 0 then
+ opt.paths = paths
end
-- find program